( function( $ ) {

    'use strict';

    var WdesPopupEditor;

    WdesPopupEditor = {
        init: function (){
            elementor.settings.page.model.on( 'change', WdesPopupEditor.onSettings );
        },

        onSettings: function (model){

            var iframe   = document.getElementById( 'elementor-preview-iframe' ),
                innerDoc = iframe.contentDocument || iframe.contentWindow.document;

            if( model.changed.hasOwnProperty( 'close_button_icon' ) ){
                var closeButton = $( '.wdes-popup-close-button', innerDoc ),
                    icon        = model.changed['close_button_icon'];

                if( ! icon.library.length ){
                    if( $( 'i', closeButton ).length ){
                        $( 'i', closeButton ).remove();
                    }
                    if($( 'img', closeButton.length )){

                        $( 'img', closeButton ).remove();
                    }
                }

                if(icon.library === 'svg'){

                    if($( 'i', closeButton ).length){
                        $( 'i', closeButton ).remove();
                        $(closeButton).append('<img src="#"  alt="popup icon"/>');
                    }

                    if(!$( 'img', closeButton ).length){
                        $(closeButton).append('<img src="#"  alt="popup icon"/>');
                    }

                    $( 'img', closeButton ).attr( 'src', icon.value.url );

                }else {
                    if($( 'img', closeButton ).length){
                        $( 'img', closeButton ).remove();
                        $(closeButton).append('<i class=""></i>');
                    }
                    if(!$( 'i', closeButton ).length){
                        $(closeButton).append('<i class=""></i>');
                    }
                    $( 'i', closeButton ).attr( 'class', icon.value );
                }

            }

            if ( model.changed.hasOwnProperty( 'use_close_button' ) ) {
                var useCloseButton = ( 'yes' === model.changed['use_close_button'] ) ? true : false,
                    closeButton    = $( '.wdes-popup-close-button', innerDoc );

                if ( useCloseButton ) {
                    closeButton.removeClass( 'hidden' );
                } else {
                    closeButton.addClass( 'hidden' );
                }
            }

            if ( model.changed.hasOwnProperty( 'use_overlay' ) ) {
                var useOverlay = ( 'yes' === model.changed['use_overlay'] ) ? true : false,
                    $overlay   = $( '.wdes-popup-overlay', innerDoc );

                if ( useOverlay ) {
                    $overlay.removeClass( 'hidden' );
                } else {
                    $overlay.addClass( 'hidden' );
                }
            }

            if( model.changed.hasOwnProperty('wdes_popup_settings_animation') ){
                var selectPopup = $('.wdes-popup', innerDoc),
                    animationValue = model.changed['wdes_popup_settings_animation'];

                WdesPopupEditor.animePopup(selectPopup, animationValue);
            }

        },

        animePopup: function ($selectedElem, animeType){
            var animeContainer =$.extend(
                {
                    targets : $('.wdes-popup-container', $selectedElem)[0]
                },
                WdesPopupEditor.animeEffects[animeType]['show']
            );

            anime(animeContainer);
        },
        animeEffects: {
            'fade': {
                'show': {
                    delay: 200,
                    opacity: {
                        value: [0, 1],
                        duration:600,
                        easing: 'easeOutQuart',
                    },
                },
                'hide': {
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                        duration:400,
                        easing: 'easeOutQuart',
                    },
                }
            },

            'zoom-in': {
                'show': {
                    duration:500,
                    delay: 200,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [0, 1]
                    },
                    scale: {
                        value:[ 0.75, 1]
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    scale: {
                        value:[ 1 , 0.75]
                    }
                }
            },

            'zoom-out': {
                'show': {
                    duration:500,
                    delay: 200,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [0, 1]
                    },
                    scale: {
                        value:[ 1.25, 1]
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    scale: {
                        value:[ 1 , 1.25]
                    }
                }
            },

            'rotate': {
                'show': {
                    duration:500,
                    delay: 200,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [0, 1]
                    },
                    scale: {
                        value:[ 0.75, 1]
                    },
                    rotate: {
                        value: [ -65, 0 ]
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    scale: {
                        value:[ 1 , 0.9]
                    }
                }
            },

            'move-up': {
                'show': {
                    duration:500,
                    delay: 200,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [0, 1]
                    },
                    translateY:{
                        value: [ 50, 1]
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    translateY:{
                        value: [ 1, 50]
                    }
                }
            },

            'flip-x': {
                'show': {
                    duration:1000,
                    delay: 200,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [0, 1]
                    },
                    rotateX:{
                        value: [ 65, 0]
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    }
                }
            },

            'flip-y': {
                'show': {
                    duration:1000,
                    delay: 200,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [0, 1]
                    },
                    rotateY:{
                        value: [ 65, 0]
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    }
                }
            },

            'bounce-in': {
                'show': {
                    duration:1000,
                    opacity: {
                        value: [0, 1],
                        delay: 500,
                        easing: 'easeOutQuart',
                    },
                    scale:{
                        value: [ 0.2, 1],
                        delay: 800,
                        elasticity: function(el, i, l) {
                            return (400 + i * 200);
                        },
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    scale: {
                        value:[ 1, 0.8 ]
                    }
                }
            },

            'bounce-out': {
                'show': {
                    duration:200,
                    opacity: {
                        value: [0, 1],
                        delay: 500,
                        easing: 'easeOutQuart',
                    },
                    scale:{
                        value: [ 1.8, 1],
                        delay: 800,
                        elasticity: function(el, i, l) {
                            return (400 + i * 200);
                        },
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeOutQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    scale: {
                        value:[ 1, 1.5 ]
                    }
                }
            },

            'slider-in-up' : {
                'show': {
                    delay: 200,
                    opacity: {
                        value: [ 0, 1 ],
                        duration: 400,
                        easing: 'easeOutQuart',
                    },
                    translateY: {
                        value: ['100vh', 0],
                        duration: 750,
                        easing: 'easeOutQuart',
                    }
                },
                'hide': {
                    duration: 400,
                    easing: 'easeInQuart',
                    opacity: {
                        value: [ 1, 0 ],
                    },
                    translateY: {
                        value: [0,'100vh'],
                    }
                }
            },

            'slider-in-right': {
                'show': {
                    delay:200,
                    opacity: {
                        value: [0, 1],
                        duration: 400,
                        easing: 'easeOutQuart',
                    },
                    translateX:{
                        value: [ '100vh', 0],
                        duration: 750,
                        easing: 'easeOutQuart',
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeInQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    translateX: {
                        value:[ 0, '100vh' ]
                    }
                }
            },

            'slider-in-down': {
                'show': {
                    delay:200,
                    opacity: {
                        value: [0, 1],
                        duration: 400,
                        easing: 'easeOutQuart',
                    },
                    translateY:{
                        value: [ '-100vh', 0],
                        duration: 750,
                        easing: 'easeOutQuart',
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeInQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    translateY: {
                        value:[ 0, '-100vh' ]
                    }
                }
            },

            'slider-in-left': {
                'show': {
                    delay:200,
                    opacity: {
                        value: [0, 1],
                        duration: 400,
                        easing: 'easeOutQuart',
                    },
                    translateX:{
                        value: [ '-100vh', 0],
                        duration: 750,
                        easing: 'easeOutQuart',
                    }
                },
                'hide': {
                    duration:400,
                    easing: 'easeInQuart',
                    opacity: {
                        value: [1, 0],
                    },
                    translateX: {
                        value:[ 0, '-100vh' ]
                    }
                }
            },

        }
    }

    $( window ).on( 'elementor:init', WdesPopupEditor.init );

}( jQuery ) );