<?php
namespace Phox_Host\Builder\Base;

use Phox_Host\Builder\Structures;

if (!defined('ABSPATH')) {
    exit; //Exit if assessed directly
}

/**
 * Abstract Class For The Theme Builder Post Type
 *
 * @package Builder
 * @since 1.8.3
 */
abstract class Post_Type
{

    /**
     * Template type arg for URL
     * @var string
     */
    public $type_tax = 'wdes_library_type';

    /**
     * Post type slug.
     *
     * @var string
     */
    public $slug = '';

    /**
     * Taps
     *
     * @var array
     */
    protected $tabs = [];


    public function __construct()
    {
        $this->tabs = $this->get_structures_for_post_type();

        add_action( 'admin_enqueue_scripts', [$this, 'template_type_form_assets']);
        add_filter( 'views_edit-' . $this->slug, array( $this, 'print_type_tabs' ) );

    }

    /**
     * Register templates post type
     *
     * @since 1.8.3
     * @return void
     */
    abstract public function register_builder();

    /**
     * Add Default Labels Value for Register Post Type
     *
     * @return array
     */
     public function register_post_type_labels() {
         return [
             'name'               => esc_html__( 'Theme Builder', 'phox-host' ),
             'singular_name'      => esc_html__( 'Template', 'phox-host' ),
             'add_new'            => esc_html__( 'Add New', 'phox-host' ),
             'add_new_item'       => esc_html__( 'Add New Template', 'phox-host' ),
             'edit_item'          => esc_html__( 'Edit Template', 'phox-host' ),
             'new_item'           => esc_html__( 'Add New Template', 'phox-host' ),
             'view_item'          => esc_html__( 'View Template', 'phox-host' ),
             'search_items'       => esc_html__( 'Search Template', 'phox-host' ),
             'not_found'          => esc_html__( 'No Templates Found', 'phox-host' ),
             'not_found_in_trash' => esc_html__( 'No Templates Found In Trash', 'phox-host' ),
             'menu_name'          => esc_html__( 'My Library', 'phox-host' ),
         ];
     }

    /**
     * Templates post type slug
     *
     * @return string
     */
    public function slug() {
        return $this->slug;
    }

    public function type_tabs_page_link ($slug){

        return admin_url( 'edit.php?post_type=' . $slug );

    }

    /**
     * Print library types tabs
     *
     * @return [type] [description]
     */
    public function print_type_tabs( $edit_links ) {


        $tabs = $this->tabs;

        $active_tab = $_GET[$this->type_tax] ?? 'wdes_popup';

        if( $active_tab == 'wdes_popup' && $_GET['post_type'] == 'wdes-theme-builder' ){

            $active_tab = 'all';

        }

        if ( ! array_key_exists( $active_tab, $tabs ) ) {
            $active_tab = 'all';
        }

        print ( '<div class="nav-tab-wrapper wdes_library_type">' );

            foreach ( $tabs as $tab => $label ) {

                $class = 'nav-tab';

                if ( $tab === $active_tab ) {
                    $class .= ' nav-tab-active';
                }

                if ( 'wdes_popup' !== $tab ) {
                    $link = add_query_arg( array( $this->type_tax => $tab ), $this->type_tabs_page_link( 'wdes-theme-builder' ) );
                } else {
                    $link = $this->type_tabs_page_link('wdes-popup');
                }

                printf( '<a href="%1$s" class="%3$s">%2$s</a>', $link, $label, $class );

            }

        print ( '</div>' );

        print ('<br>');

        return $edit_links;
    }

    /**
     * Template type popup assets
     *
     * @return void
     */
    public function template_type_form_assets() {

        $screen = get_current_screen();

        if ( $screen->id !== 'edit-' . $this->slug ) {
            return;
        }

        wp_enqueue_script(
            'wdes-templates-type-form-script',
            Phox_HOST_URI . '/assets/js/templates-type.js' ,
            ['jquery'],
            Phox_HOST_VERSION,
            true
        );

        wp_enqueue_style(
            'wdes-templates-type-form-style',
            Phox_HOST_URI . '/assets/css/templates-type.css',
            [],
            Phox_HOST_VERSION
        );

        add_action( 'admin_footer', array( $this, 'print_template_types_popup' ), 999 );

    }


    /**
     * Print template type form HTML
     *
     * @return void
     */
    public function print_template_types_popup() {

        $default_option = array(
            '' => esc_html__( 'Select...', 'phox-host' )
        );

        $template_types = $default_option + $this->tabs;
        $selected       = $_GET[$this->type_tax] ?? 'wdes_popup';
        if( $selected != 'wdes_popup' ){
            $action = add_query_arg(
                [
                    'action' => 'wdes_create_new_template',
                ],
                esc_url( admin_url( 'admin.php' ) )
            );
        }else {
            $action = add_query_arg(
                [
                    'action' => 'wdes_create_new_popup',
                ],
                esc_url( admin_url( 'admin.php' ) )
            );
        }


        print( '<div class="wdes-template-types-popup">' );

            print ( '<div class="wdes-template-types-popup-overlay"></div>' );

            print ( '<div class="wdes-template-types-popup-content">' );

                printf ( '<h3 class="wdes-template-types-popup-heading"> %s </h3>', esc_html__( 'Select Template Type', 'phox-host' ) );

                    printf ( '<form class="wdes-template-types-popup-form" id="templates_type_form" method="POST" action="%s" >', esc_url( $action ) );

                    print ( '<div class="wdes-template-types-popup-form-row">' );

                        printf ( '<label for="template_type">%s</label>', esc_html__( 'Select Type:', 'phox-host' ) );

                        print ( '<select id="template_type" name="template_type">' );

                            foreach ( $template_types as $type => $label ) {

                                printf( '<option value="%1$s" %3$s>%2$s</option>', $type, $label, selected( $selected, $type, false ) );

                            }

                        print ( '</select>' );

                    print ( '</div>' );

                    print ( '<div class="wdes-template-types-popup-form-row">' );

                        printf( '<label for="template_name">%s</label>', esc_html__( 'Template Name:', 'phox-host' ) );

                        printf( '<input type="text" id="template_name" name="template_name" placeholder="%s">', esc_html__( 'Set template name', 'phox-host' ) );

                    print ( '</div>' );

                    print ( '<div class="wdes-template-types-popup-form-actions">' );

                        printf ( '<button type="button" id="templates_type_submit" class="button button-primary button-hero">%s</button>', esc_html__( 'Create Template', 'phox-host' ) );

                    print ( '</div>' );

                print ( '</form>' );

            print ( '</div>' );

        print ( '</div>' );
    }

    /**
     * Get Structures For Post Type
     *
     * Return structures prepared for post type page tabs
     *
     * @since 2.0.0
     * @return array
     */
    public function get_structures_for_post_type(): array
    {

        return [
            "wdes_header" => esc_html__( 'Header', 'phox-host' ),
            "wdes_footer" => esc_html__( 'Footer', 'phox-host' ),
            "wdes_popup" => esc_html__( 'Popup', 'phox-host' ),
        ];

    }


}
