<?php
namespace Phox_Host\Builder\Conditions;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}

use Elementor\Controls_Manager;

/**
 * Singular Page
 *
 * Register singular page condition
 *
 * @package Builder/Conditions
 * @since 1.7.8
 */
class Singular_Page extends base_condition {

    public function id(): string
    {
        return 'singular-page';
    }


    public function label(): string
    {
        return __( 'Page', 'phox-host' );
    }


    public function group(): string
    {
        return 'singular';
    }

    public function get_verbose_items( $args ) : string {

        if ( empty( $args['pages'] ) ) {
            return __( 'All', 'phox-host' );
        }

        $result = '';
        $sep    = '';

        foreach ( $args['pages'] as $page ) {
            $result .= $sep . get_the_title( $page );
            $sep     = ', ';
        }

        return $result;
    }

    /**
     * Controls
     *
     * @return array[]
     */
    public function controls(): array
    {
        return [
            'pages' => [
                'label' => __('Select Page', 'phox-host'),
                'type'  => Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple' => true,
                'description' => __('Leave empty to apply for all pages', 'phox-host'),
                'options' => $this->option_values('page'),
                'condition' =>[]
            ]
        ];
    }

    /**
     * Condition check callback
     *
     * @return bool
     */
    public function check( $args ) {

        if ( empty( $args['pages'] ) ) {
            return is_page();
        }

        return is_page( $args['pages'] );
    }


}