<?php
namespace Phox_Host\Builder\Conditions;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}

use Elementor\Controls_Manager;

/**
 * Singular Post
 *
 * Register singular post condition
 *
 * @package Builder/Conditions
 * @since 1.7.8
 */
class Singular_Post extends base_condition {

    public function id(): string
    {
        return 'singular-post';
    }

    public function label(): string
    {
        return __( 'Post', 'phox-host' );
    }

    public function group(): string
    {
        return 'singular';
    }

    public function get_verbose_items( $args ) : string {

        if ( empty( $args['posts'] ) ) {
            return __( 'All', 'phox-host' );
        }

        $result = '';
        $sep    = '';

        foreach ( $args['posts'] as $post ) {
            $result .= $sep . get_the_title( $post );
            $sep     = ', ';
        }

        return $result;
    }

    /**
     * Controls
     *
     * @return array
     */
    public function controls(): array
    {
        return [
            'posts' => [
                'label' => __('Select Post', 'phox-host'),
                'type'  => Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple' => true,
                'description' => __('Leave empty to apply for all posts', 'phox-host'),
                'options' => $this->option_values('post'),
                'condition' =>[]
            ]
        ];
    }


    /**
     * Condition check callback
     *
     * @return bool
     */
    public function check( $args ) {

        if ( empty( $args['posts'] ) ) {
            return is_single();
        }

        return is_single( $args['posts'] );
    }
}