<?php
namespace Phox_Host\Builder;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Css_Filter;
use Elementor\Controls_Manager;
use Elementor\Utils;

class Popup_Document extends Base_Document {

    public function get_name()
    {
        return 'wdes_popup';
    }

    public static function get_title()
    {
        return __('Popup', 'phox-host');
    }

    /**
     * Register document controls.
     */
    public function register_controls(){

        parent::register_controls();

        $post_type = explode( 'stack-', $this->get_unique_name());
        $popup_id = '#wdes-popup-' . $post_type[1];

        $this->start_controls_section(
            'wdes_popup_settings',
            [
                'label' => esc_html__('Settings', 'phox-host'),
                'tab'        => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $this->add_control(
            'wdes_popup_settings_animation',
            [
                'label' => esc_html__( 'Animation', 'phox-host' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'fade'                  => esc_html__( 'Fade', 'phox-host' ),
                    'zoom-in'               => esc_html__( 'ZoomIn', 'phox-host' ),
                    'zoom-out'              => esc_html__( 'ZoomOut', 'phox-host' ),
                    'rotate'                => esc_html__( 'Rotate', 'phox-host' ),
                    'move-up'               => esc_html__( 'MoveUp', 'phox-host' ),
                    'flip-x'                => esc_html__( 'Horizontal Flip', 'phox-host' ),
                    'flip-y'                => esc_html__( 'Vertical Flip', 'phox-host' ),
                    'bounce-in'             => esc_html__( 'BounceIn', 'phox-host' ),
                    'bounce-out'            => esc_html__( 'BounceOut', 'phox-host' ),
                    'slider-in-up'          => esc_html__( 'SliderInUp', 'phox-host' ),
                    'slider-in-right'       => esc_html__( 'SliderInRight', 'phox-host' ),
                    'slider-in-down'        => esc_html__( 'SliderInDown', 'phox-host' ),
                    'slider-in-left'        => esc_html__( 'SliderInLeft', 'phox-host' ),
                ],
                'default' => 'fade'
            ]
        );
        
        $this->add_control(
            'wdes_popup_settings_open_target',
            [
                'label' => esc_html__( 'Open event', 'phox-host' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'empty'  => esc_html__( 'Not Select', 'phox-host' ),
                    'page-load' => esc_html__( 'On page load', 'phox-host' ),
                    'user-inactive' => esc_html__( 'Inactivity time after', 'phox-host' ),
                    'scroll-trigger' => esc_html__( 'Page Scrolled ', 'phox-host' ),
                    'try-exit-trigger' => esc_html__( 'Try exit ', 'phox-host' ),
                    'on-date' => esc_html__( 'On Date ', 'phox-host' ),
                    'on-time' => esc_html__( 'On Time ', 'phox-host' ),
                ],
                'default' => 'empty'
            ]
        );
        
        $this->add_control(
            'wdes_popup_settings_open_delay',
            [
                'label' => esc_html__( 'Page Open Delay (seconds)', 'phox-host' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 1,
                'min'     => 0,
                'max'     => 60,
                'condition'   => [
                        'wdes_popup_settings_open_target' => 'page-load',
                ],
            ]
        );

        $this->add_control(
            'wdes_popup_settings_user_inactivity_time',
            [
                'label' => esc_html__( 'User Inactivity Time (seconds)', 'phox-host' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 1,
                'min'     => 0,
                'max'     => 60,
                'condition'   => [
                    'wdes_popup_settings_open_target' => 'user-inactive',
                ],
            ]
        );

        $this->add_control(
            'wdes_popup_scrolled_to_value',
            [
                'label' => esc_html__( 'Scrolled Value (%)', 'phox-host' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 10,
                'min'     => 0,
                'max'     => 100,
                'condition'   => [
                    'wdes_popup_settings_open_target' => 'scroll-trigger',
                ],
            ]
        );

        $this->add_control(
            'wdes_popup_on_date_value',
            [
                'label'       => esc_html__( 'Open Date', 'phox-host' ),
                'type'        => Controls_Manager::DATE_TIME,
                'default'     => date( 'Y-m-d H:i', strtotime( '+1 month' ) + ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS ) ),
                'picker_options' => [
                    'enableTime' => true,
                ],
                'condition'   => [
                    'wdes_popup_settings_open_target' => 'on-date',
                ],
            ]
        );

        $this->add_control(
            'wdes_popup_on_time_start_value',
            [
                'label'       => esc_html__( 'Open Date', 'phox-host' ),
                'type'        => Controls_Manager::DATE_TIME,
                'default'     => '',
                'picker_options' => [
                    'noCalendar' => true,
                    'enableTime' => true,
                    'dateFormat' => 'H:i',
                ],
                'condition'   => [
                    'wdes_popup_settings_open_target' => 'on-time',
                ],
            ]
        );

        $this->add_control(
            'wdes_popup_on_time_end_value',
            [
                'label'       => esc_html__( 'End Date', 'phox-host' ),
                'type'        => Controls_Manager::DATE_TIME,
                'default'     => '',
                'picker_options' => [
                    'noCalendar' => true,
                    'enableTime' => true,
                    'dateFormat' => 'H:i',
                ],
                'condition'   => [
                    'wdes_popup_settings_open_target' => 'on-time',
                ],
            ]
        );
        
        $this->add_control(
            'wdes_popup_prevent_scrolling',
            [
                'label' => esc_html__( 'Disable Page Scrolling', 'phox-host' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'phox-host' ),
                'label_off' => esc_html__( 'No', 'phox-host' ),
            ]
        );

        $this->add_control(
            'wdes_popup_show_once',
            [
                'label' => esc_html__( 'Show once', 'phox-host' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'phox-host' ),
                'label_off' => esc_html__( 'No', 'phox-host' ),
            ]
        );
        
        $this->add_control(
            'wdes_popup_show_again_delay',
            [
                'label' => esc_html__( 'Repeat showing popup in', 'phox-host' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'  => esc_html__( 'None', 'phox-host' ),
                    'minute'  => esc_html__( 'Minute', 'phox-host' ),
                    '10minutes'  => esc_html__( '10 Minutes', 'phox-host' ),
                    '30minutes'  => esc_html__( '30 Minutes', 'phox-host' ),
                    'hour'  => esc_html__( '1 Hour', 'phox-host' ),
                    '3hours'  => esc_html__( '3 Hours', 'phox-host' ),
                    '12hours'  => esc_html__( '6 Hours', 'phox-host' ),
                    'day'  => esc_html__( 'Day', 'phox-host' ),
                    '3days'  => esc_html__( '3 Days', 'phox-host' ),
                    'week'  => esc_html__( 'Week', 'phox-host' ),
                    'month'  => esc_html__( 'Month', 'phox-host' ),
                ],
                'condition'   => [
                    'wdes_popup_show_once' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'wdes_popup_general_style',
            [
                'label' => esc_html__('General Style', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'wdes_popup_z_index',
            [
                'label' => esc_html__( 'Z-Index', 'phox-host' ),
                'type'    => Controls_Manager::NUMBER,
                'min'     => -1,
                'max'     => 50000,
                'selectors' => [
                    $popup_id => 'z-index: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();

        $this->start_controls_section(
            'wdes_popup_container_style',
            [
                'label' => esc_html__('Container', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'positions_size',
            [
                'label' => esc_html__( 'Size', 'phox-host' ),
                'type'  => Controls_Manager::HEADING
            ]
        );

        $this->add_responsive_control(
            'container_width',
            [
                'label' => esc_html__( 'Width', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px', '%'
                ],
                'range'      => [
                    'px' => [
                        'min' => 100,
                        'max' => 2000,
                    ],
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'default' => [
                        'size' => 500,
                        'unit' => 'px',
                    ],
                ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-container'  => 'width: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_control(
            'container_custom_height',
            [
                'label' => esc_html__( 'Custom Height', 'phox-host' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'phox-host' ),
                'label_off' => esc_html__( 'No', 'phox-host' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_responsive_control(
            'container_height',
            [
                'label' => esc_html__( 'Height', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px', '%'
                ],
                'range'      => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 500,
                    'unit' => 'px',
                ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-container'  => 'height: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'container_custom_height' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'position_heading',
            [
                'label' => esc_html__( 'Position', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'horizontal_position',
            [
                'label' => esc_html__( 'Horizontal', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options'     => [
                    'flex-start' => [
                        'title' => __( 'Left', 'phox-host' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'phox-host' ),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => __( 'Right', 'phox-host' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-inner' => 'justify-content: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'vertical_position',
            [
                'label' => esc_html__( 'Vertical', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options'     => [
                    'flex-start' => [
                        'title' => __( 'Left', 'phox-host' ),
                        'icon' => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'phox-host' ),
                        'icon' => 'eicon-v-align-middle',
                    ],
                    'flex-end' => [
                        'title' => __( 'Right', 'phox-host' ),
                        'icon' => 'eicon-v-align-bottom',
                    ],
                ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-inner' => 'align-items: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_position',
            [
                'label' => esc_html__( 'Content', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options'     => [
                    'flex-start' => [
                        'title' => __( 'Left', 'phox-host' ),
                        'icon' => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'phox-host' ),
                        'icon' => 'eicon-v-align-middle',
                    ],
                    'flex-end' => [
                        'title' => __( 'Right', 'phox-host' ),
                        'icon' => 'eicon-v-align-bottom',
                    ],
                ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-inner' => 'justify-content: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'container_background_heading',
            [
                'label' => esc_html__( 'Container Background', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'close_button_style_overlay_bg',
                'selector' =>  $popup_id . ' .wdes-popup-container-inner',
            ]
        );

        $this->add_control(
            'container_background_overlay_heading',
            [
                'label' => esc_html__( 'Container Overlay', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'condition' => [
                    'container_background_background' => [ 'classic', 'gradient' ],
                ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'container_background_overlay_opacity',
            [
                'label' => esc_html__( 'Opacity', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 0.01,
                    ],
                ],
                'default' => [
                    'size' => .5,
                ],
                'selectors' => [
                    $popup_id . ' .wdes-popup-container-overlay' => 'opacity: {{SIZE}};',
                ],
                'condition' => [
                    'container_background_overlay' => [ 'classic', 'gradient' ],
                    'container_background_background' => [ 'classic', 'gradient' ],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(),
            [
                'name'     => 'container_background_overlay_css_filters',
                'selector' => $popup_id . ' .wdes-popup-container-overlay',
                'condition' => [
                    'container_background_background' => [ 'classic', 'gradient' ],
                ],
            ]
        );

        $this->add_control(
            'container_background_overlay_blend_mode',
            [
                'label' => __( 'Blend Mode', 'phox-host' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '' => __( 'Normal', 'phox-host' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    $popup_id . ' .wdes-popup-container-overlay' => 'mix-blend-mode: {{VALUE}}',
                ],
                'condition' => [
                    'container_background_background' => [ 'classic', 'gradient' ],
                ],
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'other_heading',
            [
                'label' => esc_html__( 'Other Styles', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'container_padding',
            [
                'label'      => __( 'Padding', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-container-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'container_margin',
            [
                'label'      => __( 'Margin', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-container-inner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'container_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    $popup_id . ' .wdes-popup-container-inner'   => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    $popup_id . ' .wdes-popup-container-overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'container_border',
                'label'       => esc_html__( 'Border', 'phox-host' ),
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => $popup_id . ' .wdes-popup-container-inner',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'container_shadow',
                'selector' => $popup_id . ' .wdes-popup-container-inner',
            ]
        );

        $this->end_controls_section();
        
        $this->start_controls_section(
            'wdes_popup_close_button_style',
            [
                'label' => esc_html__('Close Button', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'use_close_button',
            [
                'label' => esc_html__( 'Use Close Button', 'phox-host' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'Yes', 'phox-host' ),
                'label_off' => esc_html__( 'No', 'phox-host' ),
                'return_value' => 'yes'
            ]
        );
        
        $this->add_control(
            'close_button_icon',
            [
                'label' => esc_html__( 'Icon', 'phox-host' ),
                'type'        => Controls_Manager::ICONS,
                'file'        => '',
                'default'     => [
                    'value' => 'fas fa-times',
                    'library' => 'fa-solid',
                ],
            ]
        );
        
        $this->add_control(
            'close_button_box_transform',
            [
                'label' => esc_html__( 'Icon Transform', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'close_button_icon_translate_x',
            [
                'label' => esc_html__( 'X', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => -300,
                        'max' => 300,
                    ],
                ],
                'default' => [
                    'size' => 0,
                ],
                'selectors'  => [
                     $popup_id . ' .wdes-popup-close-button'  => 'transform: translateX({{close_button_icon_translate_x.SIZE}}px) translateY({{close_button_icon_translate_y.SIZE}}px); -webkit-transform: translateX({{close_button_icon_translate_x.SIZE}}px) translateY({{close_button_icon_translate_y.SIZE}}px);',
                ],
            ]
        );

        $this->add_responsive_control(
            'close_button_icon_translate_y',
            [
                'label' => esc_html__( 'Y', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => -300,
                        'max' => 300,
                    ],
                ],
                'default'  => [
                    'size' => 0,
                ],
            ]
        );

        $this->add_control(
            'close_button_style_head',
            [
                'label' => esc_html__( 'Close Button Style', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs( 'close_button_style_tabs' );

        $this->start_controls_tab(
            'close_button_style_normal',
            [
                'label' => esc_html__( 'Normal', 'phox-host' )
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'close_button_style_normal_typography',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY
                ],
                'selector' =>  $popup_id . ' .wdes-popup-close-button',
            ]
        );

        $this->add_control(
            'close_button_style_normal_color',
            [
                'label' => esc_html__( 'Font Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                     $popup_id . ' .wdes-popup-close-button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'close_button_style_normal_bg',
                'selector' =>  $popup_id . ' .wdes-popup-close-button',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'close_button_style_normal_border',
                'selector'    =>  $popup_id . ' .wdes-popup-close-button',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'close_button_style_normal_shadow',
                'selector' =>  $popup_id . ' .wdes-popup-close-button',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'close_button_style_hover',
            [
                'label' => esc_html__( 'Hover', 'phox-host' )
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'close_button_style_hover_typography',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY
                ],
                'selector' =>   $popup_id . ' .wdes-popup-close-button:hover',
            ]
        );

        $this->add_control(
            'close_button_style_hover_color',
            [
                'label' => esc_html__( 'Font Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                      $popup_id . ' .wdes-popup-close-button:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'close_button_style_hover_bg',
                'selector' =>   $popup_id . ' .wdes-popup-close-button:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'close_button_style_hover_border',
                'selector'    =>   $popup_id . ' .wdes-popup-close-button:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'close_button_style_hover_shadow',
                'selector' =>   $popup_id . ' .wdes-popup-close-button:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        
        $this->end_controls_section();

        $this->start_controls_section(
            'wdes_popup_overlay_style',
            [
                'tab'        => Controls_Manager::TAB_STYLE,
                'label' => esc_html__('Overlay', 'phox-host'),
            ]
        );

        $this->add_control(
            'use_overlay',
            [
                'label' => esc_html__( 'Active Overlay', 'phox-host' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'yes', 'phox-host' ),
                'label_off' => esc_html__( 'no', 'phox-host' ),
                'return_value' => 'yes'
            ]
        );

        $this->add_control(
            'close_on_overlay_click',
            [
                'label' => esc_html__( 'Close On Click', 'phox-host' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'Yes', 'phox-host' ),
                'label_off' => esc_html__( 'No', 'phox-host' ),
                'return_value' => 'yes',
                'condition' => [
                    'use_overlay' => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'overlay_bg',
                'selector' =>  $popup_id . ' .wdes-popup-overlay',
                'condition' => [
                    'use_overlay' => 'yes',
                ]
            ]
        );

        $this->end_controls_section();

    }

}
