<?php
namespace Phox_Host\Builder\Popup;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}

use Elementor\Plugin;
use function Phox_Host\phox_host_core;

/**
 * Elementor Settings
 *
 * Change settings on elementor to run with popup
 *
 * @package Builder\Popup
 * @since 1.8.4
 */
class Elementor_Settings {


    public function __construct(){

        add_action( 'elementor/documents/register', [ $this, 'register_document_type' ] );
        add_action( 'template_include', [ $this, 'post_type_template' ], 9999 );
        add_action( 'elementor/editor/before_enqueue_scripts', [$this, 'editor_scripts']);
        add_action( 'elementor/frontend/before_enqueue_scripts', [$this, 'frontend_scripts']);
        add_action( 'elementor/preview/enqueue_styles', [$this, 'preview_styles']);

    }

    /**
     * Register appropriate document type for 'wdes-popup' post type
     *
     * @param  Elementor\Core\Documents_Manager $documents_manager [description]
     * @return void
     */
    public function register_document_type ($documents_manager){

        require $this->file_dir('document-type', 'popup_document.php');

        $documents_manager->register_document_type( 'wdes_popup', '\Phox_Host\Builder\Popup_Document' );

    }

    /**
     * Change the default post type template for custom one has been created for popup
     *
     * @param $template
     * @return mixed
     */
    public function post_type_template($template){

        $post_type_slug = phox_host_core()->theme_builder_popup->slug;

        if( is_singular($post_type_slug) ){

            $template = __DIR__ . '/templates/single.php';

            if( Plugin::$instance->preview->is_preview_mode() ){
                $template = __DIR__ . '/templates/editor.php';
            }

        }

        return $template;


    }

    /**
     * Enqueue plugin scripts only with elementor scripts
     *
     * @return void
     */
    public function editor_scripts() {

        $screen = get_current_screen();

        if( 'wdes-popup' !== $screen->post_type ){
            return;
        }

        wp_enqueue_script(
            'wdes_popup_editor_js',
            Phox_HOST_URI . '/assets/js/popup-editor.js',
            [
                'jquery',
                'underscore',
                'backbone-marionette',
                'wp-api-fetch',
            ],
            Phox_HOST_VERSION,
            true
        );

        wp_enqueue_script(
            'wdes-anime',
            Phox_HOST_URI . 'assets/js/libs/anime.min.js',
            [],
            '2.2.0',
            true
        );

    }
    /**
     * Enqueue plugin scripts only with elementor scripts
     *
     * @return void
     */
    public function frontend_scripts(){

        wp_enqueue_script(
            'wdes_popup_frontend',
            Phox_HOST_URI . '/assets/js/popup-frontend.js',
            [
                'jquery',
                'elementor-frontend'
            ],
            Phox_HOST_VERSION,
            true
        );

        wp_enqueue_script('wdes-micromodal');

        wp_enqueue_script('wdes-anime');
    }
    /**
     *
     * Load preview assets
     *
     * @return void
     */
    public function preview_styles() {
        wp_enqueue_style(
            'wdes-popup-preview',
            Phox_HOST_URI . 'assets/css/popup-preview.css',
            [],
            Phox_HOST_VERSION,
        );
    }
    /**
     * Get file directory
     *
     * @param string $folder
     * @param string $file
     * @return string
     */
    public function file_dir (string $folder, string $file){

        return __DIR__ . DIRECTORY_SEPARATOR . $folder . DIRECTORY_SEPARATOR .$file;

    }

}