<?php
namespace Phox_Host\Builder\Popup;

use function Phox_Host\phox_host_core;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}

/**
 * Post Type
 *
 * Register Popup Post Type
 *
 * @since 1.8.4
 * @package Builder\Popup
 */
class post_type extends \Phox_Host\Builder\Base\Post_Type {

    /**
     * Post type slug.
     *
     * @var string
     */
    public $slug = 'wdes-popup';


    /**
     * Constructor for the class
     */
    public function __construct() {

        $this->register_builder();

        add_filter( 'option_elementor_cpt_support', [ $this, 'set_elementor_support' ] );

        add_filter( 'default_option_elementor_cpt_support', [ $this, 'set_elementor_support' ] );

        add_filter( 'manage_' . $this->slug . '_posts_columns', [$this, 'set_post_columns']);

        add_action( 'manage_' . $this->slug . '_posts_custom_column', [$this, 'post_columns'], 10, 2 );

        add_action( 'admin_action_wdes_create_new_popup', [$this, 'create_template']);

        parent::__construct();

    }

    /**
     * Register templates post type
     *
     * @return void
     */
    public function register_builder(){

        $args = [
            'labels' => $this->register_post_type_labels(),
            'public'              => true,
            'hierarchical'        => false,
            'show_ui'             => true,
            'show_in_menu'        => false,
            'show_in_nav_menus'   => false,
            'can_export'          => true,
            'exclude_from_search' => true,
            'capability_type'     => 'post',
            'rewrite'             => false,
            'supports'            => ['title'],
        ];

        register_post_type(
            $this->slug,
            $args
        );

    }

    /**
     * Set required post columns
     *
     * @param array $columns
     * @return array
     */
    public function set_post_columns(array $columns ): array {

        unset( $columns['taxonomy-' . $this->type_tax ] );
        unset( $columns['date'] );

        $columns['type'] = __( 'Type', 'phox-host' );

        $columns['conditions'] = __( 'Active Conditions', 'phox-host' );

        $columns['date'] = __( 'Date', 'phox-host' );


        return $columns;

    }

    /**
     * Manage post columns content
     *
     * @param string $column
     * @param int $post_id
     * @return void
     */
    public function post_columns(string $column , int $post_id): void {

        $link = $this->type_tabs_page_link($this->slug);



        switch ( $column ) {

            case 'type':

                printf( '<a href="%1$s">%2$s</a>', $link, 'Popup' );

            break;

            case 'conditions':

                print ('<div class="wdes-builder-conditions">');

                printf(
                    '<div class="wdes-builder-conditions-list">%1$s</div>',
                    phox_host_core()->theme_builder_condition->post_conditions_verbose($post_id)
                );

                print ('</div>');

            break;
        }

    }

    /**
     * Add elementor support .
     * @param $value
     * @return array|mixed
     */
    public function set_elementor_support( $value ) {

        if ( empty( $value ) ) {
            $value = array();
        }

        return array_merge( $value, array( $this->slug() ) );
    }

    /**
     * Create new template
     *
     * @return [type] [description]
     */
    public function create_template() {

        if ( ! current_user_can( 'edit_posts' ) ) {
            wp_die(
                esc_html__( 'You don\'t have permissions to do this', 'phox-host' ),
                esc_html__( 'Error', 'phox-host' )
            );
        }

        $documents = \Elementor\Plugin::instance()->documents;
        $doc_type  = $documents->get_document_type( $this->slug );

        if ( ! $doc_type ) {
            wp_die(
                esc_html__( 'Incorrect template type. Please try again.', 'phox-host' ),
                esc_html__( 'Error', 'phox-host' )
            );
        }

        $post_data = [
            'post_status' => 'publish',
            'post_type'  => $this->slug,
            'meta_input' => [
                '_elementor_edit_mode' => 'builder',
                $doc_type::TYPE_META_KEY   => 'wdes_popup',
                '_elementor_page_settings' => [],
            ],
        ];

        $title = isset( $_REQUEST['template_name'] ) ? esc_attr( $_REQUEST['template_name'] ) : 'wdes Popup - '.rand(3,6);

        if ( $title ) {
            $post_data['post_title'] = $title;
        }

        $template_id = wp_insert_post( $post_data );

        if ( ! $template_id ) {
            wp_die(
                esc_html__( 'Can\'t create template. Please try again', 'phox-host' ),
                esc_html__( 'Error', 'phox-host' )
            );
        }

        if ( version_compare( ELEMENTOR_VERSION, '2.6.0', '<' ) ) {
            $redirect = \Elementor\Utils::get_edit_link( $template_id );
        } else {
            $redirect = \Elementor\Plugin::$instance->documents->get( $template_id )->get_edit_url();
        }

        wp_redirect( $redirect );
        die();

    }
}