<?php
namespace Phox_Host\Builder\Popup\Render;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}

abstract Class Base_Render{
    /**
     * @var null
     */
    private $settings = null;

    /**
     * @param $settings
     */
    public function __construct( $settings = [] ){
        $this->settings = $this->get_parsed_settings( $settings );

        $this->init();
    }

    /**
     * Default Settings
     *
     * @return array
     */
    public function default_settings(){
        return [];
    }

    /**
     * Get Parsed Settings
     *
     * @link https://developer.wordpress.org/reference/functions/wp_parse_args/
     * @param $settings
     * @return array
     */
    public function get_parsed_settings( $settings = [] ){

        $default = $this->default_settings();

        return wp_parse_args( $settings, $default );
    }

    /**
     * Init
     *
     * @return void
     */
    public function init(){}

    /**
     * Get Settings
     *
     * @param $setting
     * @return false|mixed|null
     */
    public function get_settings( $setting = null ){

        if( $setting ){

            return $this->settings[$setting] ?? false;

        }else{

            return $this->settings;

        }

    }

    /**
     * Get Required Settings
     *
     * @return array
     */
    public function get_required_settings(){

        $required = [];
        $settings = $this->get_settings();
        $default = $this->default_settings();

        foreach ( $default as $key => $value ){

            if( isset( $settings[ $key ] ) ){
                $required[ $key ] =$settings[ $key ];
            }

        }

        return $required;

    }

    /**
     * Get
     *
     * @param $setting
     * @param $default
     * @return false|mixed
     */
    public function get( $setting = null, $default = false ){

        if ( isset( $this->settings[ $setting ] ) ) {
            return $this->settings[ $setting ];
        } else {
            $defaults = $this->default_settings();

            return isset( $defaults[ $setting ] ) ? $defaults[ $setting ] : $default;
        }

    }

    /**
     * Get Content
     *
     * @return false|string
     */
    public function get_content() {
        ob_start();

        $this->render();

        return ob_get_clean();
    }

    /**
     * Render
     *
     * @return mixed
     */
    abstract public function render();

    /**
     * Get Render Data
     *
     * @return false
     */
    public function get_render_data() {
        return false;
    }

    /**
     * Get Name
     *
     * @return mixed
     */
    abstract public function get_name();

    /**
     * Is Editor
     *
     * @return bool
     */
    public function is_editor() {
        return isset( $_REQUEST['context'] ) && $_REQUEST['context'] === 'edit' ? true : false;
    }

}
