<?php
namespace Phox_Host\Elementor\Functions;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}

/**
 * Domain
 *
 * @package Phox
 * @author WHMCSdes
 * @link https://whmcsdes.com
 * @since 1.5.8
 */
class Domain_Class {
    /**
     * Instance .
     *
     * @var Domain_Class
     */
    protected static $_instance = null;

    /**
     * Rules for domain parser
     */
    public $rules ;

    /**
     * @var object the Domain after parsed
     */
    private $domain_check;

    /**
     * @var bool|int
     */
    private $is_php_7 ;

    /**
     * Get Domain_Class instance .
     *
     * @return Domain_Class
     */
    public static function instance() {

        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }

    }

    /**
     * Constructor.
     */
    public function __construct() {
        $this->is_php_7 = version_compare(PHP_VERSION, '8.0.49', '<=' );

        add_action( 'wp_ajax_nopriv_wdes_ajax_search_domain', [$this, 'ajax_search_domain']);
        add_action( 'wp_ajax_wdes_ajax_search_domain', [$this, 'ajax_search_domain']);
        add_action( 'wp_ajax_nopriv_wdes_ajax_search_domain_m', [$this, 'ajax_search_domain_multi_tlds']);
        add_action( 'wp_ajax_wdes_ajax_search_domain_m', [$this, 'ajax_search_domain_multi_tlds']);
        add_action( 'wp_ajax_nopriv_wdes_domain_whois', [$this, 'domain_whois']);
        add_action( 'wp_ajax_wdes_domain_whois', [$this, 'domain_whois']);
        add_action( 'wp_ajax_nopriv_wdes_domain_security', [$this, 'domain_security_nonce']);
        add_action( 'wp_ajax_wdes_domain_security', [$this, 'domain_security_nonce']);
        add_action( 'wp_head', [$this, 'domain_js_file']);
        add_action( 'wdes_domain_verify_code', [$this, 'verify_code']);

        //load php-domain-parser
        $this->load_parser_lib();

    }

    /**
     * Admin ajax for domain.
     */
    function domain_js_file() {
        echo '<script>
            /*<![CDATA[*/
            var wdes_ajax_url = "' . admin_url( 'admin-ajax.php' ) . '";
            /*]]>*/
          </script>';
    }

    /**
     * Connect from whois server.
     *
     * @param string $domain the full domain that will check.
     *
     * @return mixed|string
     */
    public function get_whois_server( $domain ) {

        $tld = ($this->is_php_7) ? $domain->getPublicSuffix() : $domain->suffix()->toString();

        $character_index = substr($tld,0,1);

        $whois_file = $this->load_whois_file($character_index);

        $response_server = '';

        if($whois_file){

            $whois_file_array = json_decode($whois_file, true);

            $custom_whois_server = apply_filters('whois_server ', [], 10, 1);

            $whois_file_array = array_merge($whois_file_array, $custom_whois_server);

            $response_server = (isset( $whois_file_array[$tld] )) ? $whois_file_array[$tld] : '';

        }

        return $response_server;
    }

    public function checkDomainRegisterStatus($whois_server,$domain){

        if( ! is_array($whois_server) || ! isset($whois_server['rdap'] ) ) return $this->check_available($whois_server,$domain, false);

        $result = ['status' => false];

        $http_client = new \WP_Http_Curl();

        $rdap_url = $whois_server['rdap'].'/domain/';
        $url = 'https://' . $rdap_url . $domain;

        $method = $whois_server['rdapCheckType'] === 'code_status' ? 'HEAD' : 'GET';

        $args = [
            'user-agent' => 'Mozilla/5.0 (platform; rv:geckoversion) Gecko/geckotrail Firefox/firefoxversion',
            'header' => [
                'User-Agent' => 'Mozilla/5.0 (platform; rv:geckoversion) Gecko/geckotrail Firefox/firefoxversion'
            ],
            'stream' => false,
            'filename' => false,
            'decompress' => 'gzip',
            'method' => $method,
            'httpversion' => '1.1',
        ];

        $request = $http_client->request($url, $args);

        if( ! is_object($request) ){

            if( $whois_server['rdapCheckType'] === 'code_status' ){

                $result = $request['response']['code'] === 200 ? ['status' => true] : ['status' => false];

            }elseif ($whois_server['rdapCheckType'] === 'bool'){

                $body = json_decode($request['body'], true);

                $result = $body['status'][0] === 'active' ? ['status' => true] : ['status' => false];

            }elseif ($whois_server['rdapCheckType'] === 'error_message'){

                $body = json_decode($request['body'], true);

                $result = ! isset($body['errors']) ? ['status' => true] : ['status' => false] ;

            } elseif ($whois_server['rdapCheckType'] === 'error_code'){

                $body = json_decode($request['body'], true);

                $result = ! isset($body['errorCode']) ? ['status' => true] : ['status' => false] ;

            }

        }else {

            if( WP_DEBUG ){

                $result = $request->errors['http_request_failed'][0];

            }

        }

        return $result;

    }

    /**
     * Check if domain is available.
     *
     * @param $whois_server
     * @param $domain
     *
     * @return array|string
     */
    public function check_available( $whois_server, $domain, $full_text ) {

        $not_found_message = '';

        if(is_array($whois_server)){
            $server = ( isset( $whois_server['whois'] ) ) ? $whois_server['whois'] : $domain;
            $not_found_message = ( isset( $whois_server['whoisWord'] ) ) ? $whois_server['whoisWord'] : '';

        }else{

            $server = $whois_server;

        }

        if ( $server && $domain ) {

            $port = ($server === 'whois.nic.ch') ? '4343' : '43';

            $server_ip = gethostbyname($server);

            $fp = @stream_socket_client( $server_ip .':'.$port, $errno, $errstr, 30 );

            if( ! $fp){

                $fp = @stream_socket_client( $server .':'.$port, $errno, $errstr, 30 );

                if( ! $fp ){
                    if( WP_DEBUG ){
                        return array(
                            'status' => "$errstr ($errno)<br />\n",
                        );

                    }else{

                        return array(
                            'status' => false,
                        );
                    }

                }

            }

            fputs( $fp, $domain . "\r\n" );
            $response = '';

            while ( ! feof( $fp ) ) {

                $response .= fgets( $fp, 128 );

            }

            fclose($fp);

            if( $full_text ){
                return $response;
            }

            if( ! empty($not_found_message)  ){

                if ( ! is_int( strpos( $response, $not_found_message ) )  ) {
                    $result = true;
                } else {
                    $result = false;
                }


            }else{
                //Fix for work with country extension
                $lowercase_response = strtolower($response);

                if ( is_int( strpos( $lowercase_response, 'domain name:' ) )  ) {
                    $result = true;
                } else {
                    $result = false;
                }
            }

            return array(
                'status' => $result,
            );

        } else {
            return array(
                'status' => false,
            );
        }

    }

    /**
     * Get the domain result by ajax.
     */
    public function ajax_search_domain() {

        if( ! isset( $_POST['security'] ) || ! wp_verify_nonce( $_POST['security'], 'check-domain-nonce' ) ){
            wp_send_json(
                ['status' => 'error', 'results_html' => '<span class="wdes-btn-token">'.esc_html__("Error on token", 'phox-host').'</span>']);
        }

        $lookup_provider_id = $_POST['lupid'];

        if( empty( $lookup_provider_id ) || ! in_array( $lookup_provider_id ,['lup-1', 'lup-2']) ){
            wp_send_json(
                ['status' => 'error', 'results_html' => '<span class="wdes-btn-token">'.esc_html__("Error on LookUp Provider", 'phox-host').'</span>']);
        }

        $domain     = sanitize_text_field ($_POST['domain']);

        $this->domain_check = $this->rules->resolve($domain);

        if( $lookup_provider_id === 'lup-2' ){

            $output = $this->godaddy_provider();

        }else{

            $output = $this->internal_provider();

        }


        wp_send_json( $output );

    }

    /**
     * Standard Lookup
     *
     * @since 1.7.9
     * @return array|bool[]|string
     */
    private function internal_provider(){

        $is_ICANN = ($this->is_php_7) ? $this->domain_check->isICANN() : $this->domain_check->suffix()->isICANN();

        if( $is_ICANN ){

            $whios_server = $this->get_whois_server( $this->domain_check );

            $domain = ($this->is_php_7) ? $this->domain_check->getRegistrableDomain() : $this->domain_check->domain()->toString();

        }else{

            $whios_server = '';

        }

        if ( empty( $whios_server ) ) {

            $output = array(
                'status'       => 'no_support',
                'domain'       => $domain,
                'results_html' => esc_html__( 'Please check the domain name or extension', 'phox-host' ),
                'message' => $domain
            );

        } else {

            $whois_server = $whios_server;
            $output       = $this->checkDomainRegisterStatus( $whois_server, $domain, false );

            $output['status'] = ( $output['status'] ) ? 'taken' : 'available';
            $output['domain'] = $domain;

            //apply filter to change the name value
            $name_property = apply_filters('change_domain_name_property_main', 'select-domain');

            // result html.
            if ( $output['status'] === 'available' ) {
                $output['message'] = apply_filters('wdes_dc_available_message',esc_html__('Congratulations!', 'phox-host') .'<b> '. $domain .'</b> '. esc_html__('is available!', 'phox-host'));
                $output['results_html']     = '<input type="hidden" name="'.$name_property.'" placeholder="'.esc_attr__('eg. example.com', 'phox-host').'" autocapitalize="none" value="' . $domain . '">';
                $output['results_html'] .= '<input type="submit" class="wdes-purchase-btn" target="_blank" value="'.esc_attr__('Purchase', 'phox-host').'">';
                $output['results_html'] .= '<span class="fas fa-shopping-cart wdes-available-dom"></span>';

            } else {
                $output['message'] = apply_filters('wdes_dc_taken_message', esc_html__('Sorry!', 'phox-host') .' <b>'. $domain .' </b>'. esc_html__('is already taken!', 'phox-host'));

                if( $_POST['settings']['whois_button'] === 'yes' ){
                    $output['results_html'] = ' <button class="wdes-btn-token"type="button" id="wdesDomainWhoisBtn"><span class="fas fa-exclamation-circle icon-taken"></span>' . esc_html__( 'Whois', 'phox-host' ) . '</button>';
                    $output['results_html'] .= wp_nonce_field('check-domain-whois-nonce', 'security-whois', true, false);
                }

                if($_POST['settings']['transfer_button'] === 'yes'){
                    $output['results_html'] .= ' <button class="wdes-btn-transfer"type="button" id="wdesDomainTransferBtn"><span class="fas fa-exclamation-circle icon-taken"></span>' . esc_html__( 'Transfer', 'phox-host' ) . '</button>';
                }
            }
        }
        return $output;
    }

    /**
     * GoDaddy Lookup
     *
     * @since 1.7.9
     * @return array
     */
    private function godaddy_provider(){

        $api_key = wdes_opts_get( 'godaddy_api_key', '' );
        $api_secret = wdes_opts_get( 'godaddy_api_secret', '' );

        $domain = ( $this->is_php_7 ) ? $this->domain_check->getRegistrableDomain() : $this->domain_check->domain()->toString();

        if( empty( $api_key ) || empty( $api_secret ) ){

            return [
                'status'       => 'error_api_key_secret',
                'domain'       => $domain,
                'results_html' => esc_html__( 'Try again later', 'phox-host' ),
                'message' => $domain
            ];

        }
        $server = 'https://api.godaddy.com/v1/domains/available';
        $data_arg = [
            'body' => [
                'domain' => '',
                'checkType' => 'FAST',
                'forTransfer' => 'false'
            ],
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => ''
            ]
        ];

        $data_arg['body']['domain'] = $domain;
        $data_arg['headers']['Authorization'] = 'sso-key '.$api_key.':'.$api_secret;

        $request = wp_remote_get($server,$data_arg);

        $response_code = wp_remote_retrieve_response_code($request);

        $response_json = json_decode(wp_remote_retrieve_body($request));

        if($response_code == 200) {

            $output['status'] = ( ! $response_json->available ) ? 'taken' : 'available';
            $output['domain'] = $response_json->domain;

            //apply filter to change the name value
            $name_property = apply_filters('change_domain_name_property_suggestion', 'select-domain');

            // result html.
            if ( $output['status'] === 'available' ) {

                $output['message'] = apply_filters('wdes_dc_available_message',esc_html__('Congratulations!', 'phox-host') .'<b> '. $domain .'</b> '. esc_html__('is available!', 'phox-host'));
                $output['results_html']     .= '<input type="hidden" name="'.$name_property.'" placeholder="'.esc_attr__('eg. example.com', 'phox-host').'" autocapitalize="none" value="' . $domain . '">';
                $output['results_html'] .= '<input type="submit" class="wdes-purchase-btn" target="_blank" value="'.esc_attr__('Purchase', 'phox-host').'">';
                $output['results_html'] .= '<span class="fas fa-shopping-cart wdes-available-dom"></span>';

            } else {
                $output['message'] = apply_filters('wdes_dc_taken_message', esc_html__('Sorry!', 'phox-host') .' <b>'. $domain .' </b>'. esc_html__('is already taken!', 'phox-host'));
            }

        }elseif($response_code == 422){

            $output = array(
                'status'       => 'no_support',
                'domain'       => $domain,
                'results_html' => esc_html__( 'Please check the domain name or extension', 'phox-host' ),
                'message' => $domain
            );

        }else{

            $output = [
                'status'       => $response_json->code,
                'domain'       => $domain,
                'results_html' => $response_json->code,
                'message' => $response_json->message
            ];

        }

        return $output;
    }

    /**
     * Get the domain whois.
     *
     * @return  string $response_server
     */
    public function domain_whois(){
        if(! isset( $_POST['security'] ) || ! wp_verify_nonce( $_POST['security'], 'check-domain-whois-nonce' ) ){
            wp_send_json(
                ['whois' => esc_html__("Error on token", 'phox-host')]);
        }

        $domain     = sanitize_text_field ( $_POST['domain'] );

        $domain_check = $this->rules->resolve($domain);

        $whios_server = $this->get_whois_server( $domain_check );

        $whois_raw_data = $this->check_available( $whios_server, $domain, true );

        /**
         * ToDo : split by new line /n and then filter on it
         */
        $register_whois_server = trim(explode('Registrar URL:',explode('Registrar WHOIS Server:',$whois_raw_data)[1])[0]);

        if( ! empty( $register_whois_server ) ){

            $whios_server[0] = $register_whois_server;

            $response_server ['whois']= $this->check_available( $whios_server, $domain, true );

        }else{

            $response_server ['whois'] = $whois_raw_data;

        }

        return wp_send_json($response_server);
    }

    /**
     * Get the domain Tlds result by ajax.
     */
    public function ajax_search_domain_multi_tlds(){

        if(! isset( $_POST['security'] ) || ! wp_verify_nonce( $_POST['security'], 'check-domain-nonce' ) ){
            wp_send_json(
                ['whois' => esc_html__("Error on token", 'phox-host')]);
        }

        $lookup_provider_id = $_POST['lupid'];

        if( empty( $lookup_provider_id ) || ! in_array( $lookup_provider_id ,['lup-1', 'lup-2']) ){
            wp_send_json(
                ['status' => 'error', 'results_html' => '<span class="wdes-btn-token">'.esc_html__("Error on LookUp Provider", 'phox-host').'</span>']);
        }

        $response = ['result' => 'error'];

        $tlds = ( !empty($_POST['tlds']) ) ? $_POST['tlds'] : false;

        $domain = ( ! empty($_POST['domain']) ) ? sanitize_text_field($_POST['domain']) : false ;

        $sld = ( ! empty($_POST['sld']) ) ? sanitize_text_field($_POST['sld']) : false ;

        if( is_string( $domain ) && is_array( $tlds ) ){

            $domain_parse = $this->rules->resolve($domain);

            $split_tld_form_domain = explode($sld, ($this->is_php_7) ? $domain_parse->getRegistrableDomain() : $domain_parse->domain()->toString());
            if( ! isset( $split_tld_form_domain[1] ) ){
                exit();
            }

            $is_ICANN = ($this->is_php_7) ? $domain_parse->isICANN() : $domain_parse->suffix()->isICANN();

            if( $is_ICANN ){

                $filter_domain_tld = array_filter($tlds, function( $tld )use( $domain_parse ){
                    $registrable_domain = ($this->is_php_7) ? $domain_parse->getPublicSuffix() : $domain_parse->registrableDomain()->toString();
                    return $tld !== $registrable_domain;
                });

                if( ! empty ( $filter_domain_tld ) ){

                    $response ['result'] = 'success';

                    foreach ( $filter_domain_tld as $tld_item ){

                        $single_domain = $sld . '.' . $tld_item;

                        $this->domain_check = $this->rules->resolve($single_domain);

                        if( $lookup_provider_id === 'lup-2' ){

                            $single_domain_status = $this->godaddy_provider();

                        }else{

                            $single_domain_status = $this->internal_provider();

                        }

                        $response['data'][$tld_item] = $single_domain_status;

                        $this->domain_check = '';
                    }

                }

            }

        }else{
            exit();
        }

        wp_send_json( $response );
    }

    /**
     * Verify code
     */
    public function verify_code() {

        echo '<input type="hidden" name="token" value="0811bf819565bf8142cc613d099e85a27ec1204c">';

    }

    /**
     * Load 'php-domain-parser' library files
     *
     * @see https://github.com/jeremykendall/php-domain-parser/tree/5.7.2
     * @see https://github.com/jeremykendall/php-domain-parser/tree/6.3.0
     * @throws \Exception
     */
    private function load_parser_lib(){

        if( $this->is_php_7 ){

            $files = ['PublicSuffixListSection', 'Rules', 'IDNAConverterTrait', 'DomainInterface', 'PublicSuffix', 'Domain', 'Converter', 'Exception','Exception/CouldNotResolvePublicSuffix', 'Exception/InvalidDomain', 'Exception/CouldNotLoadRules', 'Exception/InvalidLabelKey', 'Exception/InvalidLabel','Exception/CouldNotResolveSubDomain'];
            $path = Phox_HOST_PATH.'includes/elementor/libs/domain/php-domain-parser/';

        }else{

            $files = ['DomainNameResolver','PublicSuffixList', 'Stream','CannotProcessHost','UnableToLoadResource','Rules', 'IdnaInfo','Idna','Host','DomainName','Domain','DomainNameProvider','EffectiveTopLevelDomain','Suffix','RegisteredName','DomainNameProvider','ResolvedDomainName','ResolvedDomain','SyntaxError'];
            $path = Phox_HOST_PATH.'includes/elementor/libs/domain/php-domain-parser-v8/';

        }

        foreach ($files as $file){
            $file_path = $path.$file.'.php';
            if(file_exists($file_path)){
                require_once $file_path;
            }else{
                throw new \Exception('There are missing file from php-domain-parser');
            }
        }

        $this->rules = ($this->is_php_7) ? \Pdp\Rules::createFromPath($path.'data/public_suffix_list.dat') : \Pdp\Rules::fromPath($path.'data/public_suffix_list.dat');

    }

    /**
     * Load Whois file
     *
     * @param string $file_name
     *
     * @return string $whois_file
     */
    public function load_whois_file($file_name){

        $file_dir = plugin_dir_path( __FILE__ ).'whois/'.$file_name.'.json';
        $file_dir_open = fopen($file_dir,'r');
        $whois_file = fread($file_dir_open, filesize($file_dir));
        fclose($file_dir_open);

        $custom_file = plugin_dir_path( __FILE__ ).'whois/'.$file_name.'-custom.json';

        if(file_exists($custom_file)){
            $file_custom_dir_open = fopen($custom_file,'r');
            $whois_file_custom = fread($file_custom_dir_open, filesize($custom_file));
            fclose($file_custom_dir_open);

            $whois_file_json = json_decode($whois_file, true);
            $whois_file_custom_json = json_decode($whois_file_custom, true);

            if( ! empty($whois_file_custom_json) ){
                foreach ($whois_file_custom_json as $tld => $tld_data){
                    $whois_file_json[$tld] = $tld_data;
                }

                $whois_file = json_encode($whois_file_json);
            }

        }

        return $whois_file;
    }

    /**
     * Generate domain search nonce field
     *
     * @return void
     */
    public function domain_security_nonce()
    {
        $response = [
            'domainSecurityNonce' => wp_nonce_field('check-domain-nonce', 'security', false, false)
        ];

        wp_send_json($response);
    }

}
