<?php
namespace Phox_Host\Elementor\Functions\WHMCS;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}
/**
 * WHMCS Products Handler
 *
 * @since 1.8.4
 */

trait Products {

    /**
     * Set data that come from `get_option` function

     * @since  1.8.4
     * @access public
     * @var array
     */
    private $products_list = [];

    /**
     * First product uid
     *
     * @since  1.8.4
     * @access public
     * @var string
     */
    private $first_product_id ;

    /**
     * Last product uid
     *
     * @since  1.8.4
     * @access public
     * @var string
     */
    private $last_product_id ;

    /**
     * Currencies
     *
     * @since  1.8.4
     * @access public
     * @var array
     */
    private $currencies ;

    public function set_first_product_id(){

        if( version_compare(phpversion(), '7.3.1', '<') ){

            foreach ( $this->products_list['products'] as $uid => $product ){

                $this->first_product_id = $uid;

                break;
            }

        }else{

            $this->first_product_id = array_key_first($this->products_list['products']);

        }

    }

    public function set_last_product_id(){

        if( version_compare(phpversion(), '7.3.1', '<') ){

            foreach ( $this->products_list['products'] as $uid => $product ){

                $this->last_product_id = $uid;

            }

        }else{

            $this->last_product_id = array_key_last($this->products_list['products']);

        }

    }

    /**
     * Get Products names
     *
     * @since  1.8.4
     * @return array
     */
    public function get_products_names(): array
    {
        $names = [];

        foreach ($this->products_list['products'] as $pid => $product){

            $names [$pid] = $product['name'];

        }

        return $names;

    }

    /**
     * Get list of currencies
     *
     * @return array
     */
    public function get_product_currencies(): array
    {

        $currencies_keys = [];

        $this->set_last_product_id();

        if( version_compare(phpversion(), '7.3.1', '<') ){

            foreach ( $this->products_list['products'] as $uid => $product ){

                $this->first_product_id = $uid;

                $currencies_keys = array_keys($product['pricing']);

                break;
            }

        }else{

            $currencies_keys = array_keys($this->products_list['products'][$this->last_product_id]['pricing']);

        }

        foreach ( $currencies_keys as $item ) {

            $this->currencies[$item] = $item;

        }

        return $this->currencies;

    }

    public function get_currency_prefix( $currency ){

        if( empty($currency) ) return '$';

        $prefix = $this->products_list['products'][$this->last_product_id]['pricing'][$currency]['prefix'];

        return ! empty($prefix) ? $prefix : 'No Prefix';


    }

    /**
     * Get price for product
     *
     * @param $upid
     * @param $currency
     * @param $payment_type
     * @return string
     */
    public function get_price( $upid, $currency, $payment_type ): string
    {

        if ( empty($upid) && empty($currency) && empty($payment_type)) return '0.00';

        return $this->products_list['products'][$upid]['pricing'][$currency][$payment_type] ?? '0.00';

    }

    /**
     * Get products description
     *
     * @return array
     */
    public function get_products_description(): array
    {

        $description = [];

        foreach ($this->products_list['products'] as $pid => $product){

            $full_text = $product['description'] ?? '';

            $split_text = preg_split("/\r\n|\n|\r/", $full_text);

            if( ! empty( $split_text ) ){

                foreach ( $split_text as $key => $text ){

                    if( ! empty( $text ) ){

                        $description [$pid][$key]['item_title'] = strip_tags($text);
                        $description [$pid][$key]['item_description'] = '';
                        $description [$pid][$key]['item_description_icon' ] = null;
                        $description [$pid][$key]['item_decoration'] = 'icon';
                        $description [$pid][$key]['item_icon'] = ['value' => 'fas fa-flag', 'library' => 'fa-solid'];
                        $description [$pid][$key]['item_image'] = null;

                    }

                }
            }

        }

        return $description;

    }

    public function get_products_url(){

        $urls = [];

        foreach ($this->products_list['products'] as $pid => $product){

            $urls[$pid]['url'] = $product['product_url'] ?? '';

        }

        return $urls;

    }

}