<?php
namespace Phox_Host\Elementor\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit; //Exit if assessed directly
}
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Icons_Manager;
use Phox_Host\Elementor\Base\Base_Widget;
/**
 * Progress widget.
 *
 * Progress widget that will display in Phox category
 *
 * @package Elementor\Widgets
 * @since 1.8.1
 */
class Progress extends Base_Widget {

    /**
     * Get Widget name
     *
     * Retrieve Progress widget name
     *
     * @return string Widget name
     * @since  1.8.1
     * @access public
     *
     */
    public function get_name() {
        return 'wdes_progress';
    }

    /**
     * Get Widget title
     *
     * Retrieve Progress widget title
     *
     * @return string Widget title
     * @since  1.8.1
     * @access public
     *
     */
    public function get_title() {
        return __( 'Progress', 'phox-host' );
    }

    /**
     * Get Widget icon
     *
     * Retrieve Progress widget icon
     *
     * @return string Widget icon
     * @since  1.8.1
     * @access public
     *
     */
    public function get_icon() {
        return 'wdes-widget-elementor wdes-widget-progress';
    }


    /**
     * Get Widget keywords
     *
     * Retrieve the list of keywords the widget belongs to.
     *
     * @return array widget keywords.
     * @since  1.8.1
     * @access public
     *
     */
    public function get_keywords() {
        return [ 'progress', ' bar', 'circle'];
    }

    /**
     * Get script dependencies.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @return array Widget scripts dependencies.
     * @since 1.8.1
     * @access public
     *
     */
    public function get_script_depends() {
        return ['wdes-anime', 'wdes-circle-progress'];
    }

    /**
     * Register Progress widget controls
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.8.1
     * @access protected
     */
    protected function register_controls() {

        $class_prefix = '.wdes-progress-bar';

        $css_scheme = [
            'instance'         => $class_prefix,
            'title'            => $class_prefix . '-title',
            'title_icon'       => $class_prefix . '-title-icon',
            'title_text'       => $class_prefix . '-title-text',
            'progress_wrapper' => $class_prefix . '-wrapper',
            'status_bar'       => $class_prefix . '-status-bar',
            'percent'          => $class_prefix . '-percent',
            'circle_number'    => '.circle-counter .circle-val',
            'circle_prefix'    =>  '.circle-counter-prefix',
            'circle_suffix'    =>  '.circle-counter-suffix',
            'circle_title'     =>  '.circle-counter .circle-counter-title',
            'circle_subtitle'  =>  '.circle-counter .circle-counter-subtitle',
        ];

        $this->start_controls_section(
            'section_progress',
            [
                'label' => esc_html__('Progress', 'phox-host')
            ]
        );

        $this->add_control(
            'progress_type',
            [
                'label' => esc_html__( 'Type', 'phox-host' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'bar',
                'options' => [
                    'bar' => esc_html__( 'Bar', 'phox-host' ),
                    'circle' => esc_html__( 'Circle', 'phox-host' ),
                ]

            ]
        );

        $this->add_control(
            'progress_bar_presets',
            [
                'label' => esc_html__( 'Progress bar presets', 'phox-host' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'type-1',
                'options' => [
                    'type-1' => esc_html__( 'Inside the bar', 'phox-host' ),
                    'type-2' => esc_html__( 'Placed above', 'phox-host' ),
                    'type-3' => esc_html__( 'Show as tip', 'phox-host' ),
                    'type-4' => esc_html__( 'On the right', 'phox-host' ),
                    'type-5' => esc_html__( 'Inside the empty bar', 'phox-host' ),
                    'type-6' => esc_html__( 'Inside the bar with title', 'phox-host' ),
                ],
                'condition'   => [
                    'progress_type' => 'bar',
                ]
            ]
        );

        $this->add_control(
            'progress_bar_title',
            [
                'label' => esc_html__( 'Title', 'phox-host' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Insert Your Title', 'phox-host' ),
                'default'     => esc_html__( 'Title', 'phox-host' ),
                'label_block' => true,
                'condition'   => [
                    'progress_type' => 'bar',
                ]
            ]
        );

        $this->add_control(
            'progress_bar_icon',
            [
                'label' => esc_html__( 'Icon', 'phox-host' ),
                'type'        => Controls_Manager::ICONS,
                'file'        => '',
                'default'     => [
                    'value' => 'fas fa-arrows-alt',
                    'library' => 'fa-solid'
                ],
                'label_block' => true,
                'condition'   => [
                    'progress_type' => 'bar',
                ]
            ]
        );

        $this->add_control(
            'progress_bar_percent',
            [
                'label' => esc_html__( 'Percentage', 'phox-host' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 50,
                'min'     => 0,
                'max'     => 100,
                'condition'   => [
                    'progress_type' => 'bar',
                ]
            ]
        );

        /**
         * Circle
         */

        $this->add_control(
            'percent_value',
            [
                'label' => esc_html__( 'Percent Value', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    '%',
                ],
                'range'      => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unite' => '%',
                    'size'  => '50'
                ],
                'condition'   => [
                    'progress_type' => 'circle',
                ]
            ]
        );


        $this->add_control(
            'progress_circle_prefix',
            [
                'label' => esc_html__( 'Prefix', 'phox-host' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( '', 'phox-host' ),
                'default'     => esc_html__( '+', 'phox-host' ),
                'condition'   => [
                    'progress_type' => 'circle',
                ]
            ]
        );

        $this->add_control(
            'progress_circle_suffix',
            [
                'label' => esc_html__( 'Suffix', 'phox-host' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( '%', 'phox-host' ),
                'default'     => esc_html__( '%', 'phox-host' ),
                'condition'   => [
                    'progress_type' => 'circle',
                ]
            ]
        );

        $this->add_control(
            'progress_circle_title',
            [
                'label' => esc_html__( 'Title', 'phox-host' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Title', 'phox-host' ),
                'default'     => esc_html__( 'Title', 'phox-host' ),
                'condition'   => [
                    'progress_type' => 'circle',
                ]
            ]
        );

        $this->add_control(
            'progress_circle_subtitle',
            [
                'label' => esc_html__( 'Subtitle', 'phox-host' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Subtitle', 'phox-host' ),
                'default'     => esc_html__( 'Subtitle', 'phox-host' ),
                'condition'   => [
                    'progress_type' => 'circle',
                ]
            ]
        );

        $this->add_control(
            'progress_circle_percent_position',
            [
                'label' => esc_html__( 'Percent Position', 'phox-host' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'in-circle',
                'options' => [
                    'in-circle'  => esc_html__( 'Inside Of Circle', 'phox-host' ),
                    'out-circle'  => esc_html__( 'Outside Of Circle', 'phox-host' ),
                ],
                'condition'   => [
                    'progress_type' => 'circle',
                ]
            ]
        );

        $this->add_control(
            'progress_circle_labels_position',
            [
                'label' => esc_html__( 'Labels Position', 'phox-host' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'out-circle',
                'options' => [
                    'in-circle'  => esc_html__( 'Inside Of Circle', 'phox-host' ),
                    'out-circle'  => esc_html__( 'Outside Of Circle', 'phox-host' ),
                ],
                'condition'   => [
                    'progress_type' => 'circle',
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'progress_bar_style_bar',
            [
                'label' => esc_html__('Bar', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'condition'   => [
                    'progress_type' => 'bar',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_bar_height',
            [
                'label' => esc_html__( 'Height', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 500,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['progress_wrapper'] => 'height: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_bar_margin',
            [
                'label' => esc_html__( 'Margin', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['progress_wrapper'] => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'progress_bar_style_bar_bg',
                'selector' => '{{WRAPPER}} ' . $css_scheme['progress_wrapper'],
            ]

        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'progress_bar_style_bar_border',
                'label'       => esc_html__( 'Border', 'phox-host' ),
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} ' . $css_scheme['progress_wrapper'],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_bar_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['progress_wrapper'] => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'progress_bar_style_bar_border_radius',
                'selector' => '{{WRAPPER}} ' . $css_scheme['progress_wrapper'],
            ]
        );

        $this->add_control(
            'progress_bar_style_status_bar',
            [
                'label' => esc_html__( 'Status Bar', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'progress_bar_style_status_bar_bg',
                'selector' => '{{WRAPPER}} ' . $css_scheme['status_bar'],
            ]

        );

        $this->add_responsive_control(
            'progress_bar_style_status_bar_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['status_bar'] => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        /**
         * Title Style Section
         */
        $this->start_controls_section(
            'progress_bar_style_status_title',
            [
                'label' => esc_html__('Title', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false,
                'condition'   => [
                    'progress_type' => 'bar',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_status_title_alignment',
            [
                'label' => esc_html__( 'Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options'     => [
                    'flex-start' => [
                        'title' => esc_html__( 'Start', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-left' : 'eicon-h-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'End', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-right' : 'eicon-h-align-left',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} '. $css_scheme['title'] => 'align-self: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'progress_bar_style_status_title_bg',
                'selector' => '{{WRAPPER}} ' . $css_scheme['title'],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'progress_bar_style_status_title_border',
                'label'       => esc_html__( 'Border', 'phox-host' ),
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} ' . $css_scheme['title'],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_status_title_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' .$css_scheme['title'] => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'progress_bar_style_status_title_box_shadow',
                'selector' => '{{WRAPPER}} ' . $css_scheme['title'],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_status_title_padding',
            [
                'label' => esc_html__( 'Padding', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['title'] => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'progress_bar_style_status_title_margin',
            [
                'label' => esc_html__( 'Margin', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['title'] => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'progress_bar_style_status_title_icon',
            [
                'label' => esc_html__( 'Icon', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'progress_bar_style_status_title_icon_color',
            [
                'label' => esc_html__( 'Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ' . $css_scheme['title_icon'] => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_status_title_icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 10,
                        'max' => 200,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['title_icon'] => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_status_title_icon_margin',
            [
                'label' => esc_html__( 'Margin', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['title_icon'] => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'progress_bar_style_status_title_text',
            [
                'label' => esc_html__( 'Text', 'phox-host' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'progress_bar_style_status_title_text_color',
            [
                'label' => esc_html__( 'Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ' . $css_scheme['title_text'] => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'progress_bar_style_status_title_text_typo',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY
                ],
                'selector' => '{{WRAPPER}} ' . $css_scheme['title_text'] ,
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_status_title_text_align',
            [
                'label' => esc_html__( 'Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'flex-start' => [
                        'title' => esc_html__( 'Start', 'phox-host' ),
                        'icon'  => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'End', 'phox-host' ),
                        'icon'  => 'eicon-v-align-bottom',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} '. $css_scheme['title_text'] => 'align-self: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        /**
         * Percent Style Section
         */

        $this->start_controls_section(
            'progress_bar_style_percent',
            [
                'label' => esc_html__('Percentage', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false,
                'condition'   => [
                    'progress_type' => 'bar',
                ],
            ]
        );

        $this->add_control(
            'progress_bar_style_percent_width',
            [
                'label' => esc_html__( 'Width', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 20,
                        'max' => 200,
                    ],
                ],
                'condition'   => [
                    'progress_bar_presets' => 'type-3',
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['percent'] => 'width: {{SIZE}}{{UNIT}}; margin-right: calc( {{SIZE}}{{UNIT}}/-2 );',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_percent_alignment',
            [
                'label' => esc_html__( 'Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'flex-start' => [
                        'title' => esc_html__( 'Start', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-left' : 'eicon-h-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'End', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-right' : 'eicon-h-align-left',
                    ],
                ],
                'condition'   => [
                    'progress_bar_presets' => ['type-1', 'type-2' ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} '.$css_scheme['percent']  => 'align-self: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'progress_bar_style_percent_bg',
                'selector' => '{{WRAPPER}} ' . $css_scheme['percent'],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'progress_bar_presets_border',
                'label'       => esc_html__( 'Border', 'phox-host' ),
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} ' . $css_scheme['percent'],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_percent_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['percent'] => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'progress_bar_style_percent_box_shadow',
                'selector' => '{{WRAPPER}} ' . $css_scheme['percent'],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_percent_margin',
            [
                'label' => esc_html__( 'Margin', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['percent'] => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_percent_padding',
            [
                'label' => esc_html__( 'Padding', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['percent'] => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'progress_bar_style_percent_color',
            [
                'label' => esc_html__( 'Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ' . $css_scheme['percent'] => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'progress_bar_style_percent_typo',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY
                ],
                'selector' => '{{WRAPPER}} ' . $css_scheme['percent'],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_percent_suffix_font',
            [
                'label' => esc_html__( 'Suffix Font Size', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px', 'em', 'rem'
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' .$css_scheme['percent'] . ' .wdes-progress-bar-percent-suffix '  => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_bar_style_percent_suffix_alignment',
            [
                'label' => esc_html__( 'Percent Suffix Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'flex-start' => [
                        'title' => esc_html__( 'Start', 'phox-host' ),
                        'icon'  => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-v-align-middle',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'End', 'phox-host' ),
                        'icon'  => 'eicon-v-align-bottom',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} '. $css_scheme['percent'] . ' .wdes-progress-bar-percent-suffix ' => 'align-self: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        /**
         * Style Circle Global Settings
         */
        $this->start_controls_section(
            'progress_circle_style_global',
            [
                'label' => esc_html__('Global', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false,
                'condition'   => [
                    'progress_type' => 'circle',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_global_circle_size',
            [
                'label' => esc_html__( 'Circle Size', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 100,
                        'max' => 900,
                    ],
                ],
                'default' => [
                    'unit'  => 'px',
                    'size'  => 400
                ]
            ]
        );

        $this->add_control(
            'progress_circle_style_global_stroke',
            [
                'label' => esc_html__( 'Stroke', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit'  => 'px',
                    'size'  => 30
                ]
            ]
        );

        $this->add_control(
            'progress_circle_style_global_stroke_type',
            [
                'label'        => esc_html__( 'Stroke Type', 'phox-host' ),
                'type'         => Controls_Manager::SELECT,
                'label_block'  => false,
                'options'      => [
                    'color'    => esc_html__('Color', 'phox-host'),
                    'gradient' => esc_html__('Gradient', 'phox-host')
                ],
                'default' => 'color',
            ]
        );

        $this->add_control(
            'progress_circle_style_global_value_color_stroke',
            [
                'label'     => esc_html__( 'Value Color Stroke', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#6ec1e4',
                'condition'   => [
                    'progress_circle_style_global_stroke_type' => 'color',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_global_value_gradient_a_stroke',
            [
                'label' => esc_html__( 'Value Gradient A Stroke', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#6ec1e4',
                'condition'   => [
                    'progress_circle_style_global_stroke_type' => 'gradient',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_global_value_gradient_b_stroke',
            [
                'label' => esc_html__( 'Value Gradient B Stroke', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#b6e0f1',
                'condition'   => [
                    'progress_circle_style_global_stroke_type' => 'gradient',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_global_value_gradient_angle',
            [
                'label' => esc_html__( 'Value Gradient Angle', 'phox-host' ),
                'type'    => Controls_Manager::NUMBER,
                'default'   => 45,
                'min'       => 0,
                'max'       => 360,
                'step'      => 1,
                'condition'   => [
                    'progress_circle_style_global_stroke_type' => 'gradient',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_global_bg_stroke',
            [
                'label' => esc_html__( 'Background Stroke', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#e6e9ec',
            ]
        );

        $this->add_control(
            'progress_circle_style_global_linecap',
            [
                'label' => esc_html__( 'lineCap', 'phox-host' ),
                'type'        => Controls_Manager::SELECT,
                'label_block' => false,
                'default'      =>'butt',
                'options'     => [
                    'butt'   => esc_html__('Butt', 'phox-host'),
                    'round'  => esc_html__('Round', 'phox-host'),
                    'square' => esc_html__('Square', 'phox-host'),
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_global_duration',
            [
                'label' => esc_html__( 'Animation Duration', 'phox-host' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 1000,
                'min'     => 100,
                'step'    => 100,
            ]
        );

        $this->end_controls_section();

        /**
         * Style Circle Number
         */
        $this->start_controls_section(
            'progress_circle_style_number',
            [
                'label' => esc_html__('Number', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false,
                'condition'   => [
                    'progress_type' => 'circle',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_number_color',
            [
                'label' => esc_html__( 'Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ' . $css_scheme['circle_number']  => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'progress_circle_style_number_typo',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY
                ],
                'selector' => '{{WRAPPER}} ' . $css_scheme['circle_number'],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_padding',
            [
                'label' => esc_html__( 'Padding', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} '. $css_scheme['circle_number']  => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_prefix_font_size',
            [
                'label' => esc_html__( 'Prefix Font Size', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px', 'em', 'rem'
                ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 200,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['circle_number'] .' '. $css_scheme['circle_prefix']   => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_prefix_gap',
            [
                'label' => esc_html__( 'Prefix Gap', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 30,
                    ],
                ],
                'selectors'  => [
                    'body:not(.rtl) {{WRAPPER}} ' . $css_scheme['circle_number'] .' '. $css_scheme['circle_prefix'] => 'margin-right: {{SIZE}}{{UNIT}}',
                    'body.rtl {{WRAPPER}} ' . $css_scheme['circle_number'] .' '. $css_scheme['circle_prefix'] => 'margin-left: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_prefix_alignment',
            [
                'label' => esc_html__( 'Prefix Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'flex-start' => [
                        'title' => esc_html__( 'Top', 'phox-host' ),
                        'icon'  => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Bottom', 'phox-host' ),
                        'icon'  => 'eicon-v-align-bottom',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['circle_number'] .' '. $css_scheme['circle_prefix'] => 'align-self: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_suffix_font_size',
            [
                'label' => esc_html__( 'Suffix Font Size', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px', 'em', 'rem'
                ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 200,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['circle_number'] .' '. $css_scheme['circle_suffix']  => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_suffix_gap',
            [
                'label' => esc_html__( 'Suffix Gap', 'phox-host' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 30,
                    ],
                ],
                'selectors'  => [
                    'body:not(.rtl) {{WRAPPER}} '. $css_scheme['circle_number'] .' '. $css_scheme['circle_suffix'] => 'margin-right: {{SIZE}}{{UNIT}}',
                    'body.rtl {{WRAPPER}} ' . $css_scheme['circle_number'] .' '. $css_scheme['circle_suffix'] => 'margin-left: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_suffix_alignment',
            [
                'label' => esc_html__( 'Suffix Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'flex-start' => [
                        'title' => esc_html__( 'Top', 'phox-host' ),
                        'icon'  => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Bottom', 'phox-host' ),
                        'icon'  => 'eicon-v-align-bottom',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['circle_number'] .' '. $css_scheme['circle_suffix'] => 'align-self: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_number_alignment',
            [
                'label' => esc_html__( 'Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'left' => [
                        'title' => esc_html__( 'Start', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-left' : 'eicon-h-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'End', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-right' : 'eicon-h-align-left',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} '.$css_scheme['circle_number']  => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        /**
         * Style Circle Title
         */
        $this->start_controls_section(
            'progress_circle_style_title',
            [
                'label' => esc_html__('Title', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false,
                'condition'   => [
                    'progress_type' => 'circle',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_title_color',
            [
                'label' => esc_html__( 'Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ' . $css_scheme['circle_title'] => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'progress_circle_style_title_typo',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY
                ],
                'selector' => '{{WRAPPER}} ' . $css_scheme['circle_title'],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_title_padding',
            [
                'label' => esc_html__( 'Padding', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['circle_title'] => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_title_alignment',
            [
                'label' => esc_html__( 'Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'left' => [
                        'title' => esc_html__( 'Start', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-left' : 'eicon-h-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'End', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-right' : 'eicon-h-align-left',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} '.$css_scheme['circle_title']  => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        /**
         * Style Circle Title
         */
        $this->start_controls_section(
            'progress_circle_style_subtitle',
            [
                'label' => esc_html__('Subtitle', 'phox-host'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false,
                'condition'   => [
                    'progress_type' => 'circle',
                ],
            ]
        );

        $this->add_control(
            'progress_circle_style_subtitle_color',
            [
                'label' => esc_html__( 'Color', 'phox-host' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ' . $css_scheme['circle_subtitle'] => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'progress_circle_style_subtitle_typo',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_PRIMARY
                ],
                'selector' => '{{WRAPPER}} ' . $css_scheme['circle_subtitle'],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_subtitle_padding',
            [
                'label' => esc_html__( 'Padding', 'phox-host' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} ' . $css_scheme['circle_subtitle'] => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'progress_circle_style_subtitle_alignment',
            [
                'label' => esc_html__( 'Alignment', 'phox-host' ),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'left' => [
                        'title' => esc_html__( 'Start', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-left' : 'eicon-h-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'phox-host' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'End', 'phox-host' ),
                        'icon'  => ! is_rtl() ? 'eicon-h-align-right' : 'eicon-h-align-left',
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} '.$css_scheme['circle_subtitle']  => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render
     *
     * @since  1.8.1
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $progress_settings = [];

        if( $settings['progress_type'] === 'bar' ){

            $progress_settings = [
                'type'    => $settings['progress_type'],
                'preset'  => $settings['progress_bar_presets'],
                'title'   => $settings['progress_bar_title'],
                'icon'    => isset($settings['progress_bar_icon']['value']) ? $settings['progress_bar_icon'] : null,
                'percent' => $settings['progress_bar_percent']
            ];

        }

        if($settings['progress_type'] === 'circle'){
            $progress_settings = [
                'type'             => $settings['progress_type'],
                'percentValue'     => $settings['percent_value'],
                'percentPosition'  => $settings['progress_circle_percent_position'],
                'labelsPosition'   => $settings['progress_circle_labels_position'],
                'prefix'           => $settings['progress_circle_prefix'],
                'suffix'           => $settings['progress_circle_suffix'],
                'title'           => $settings['progress_circle_title'],
                'subtitle'        => $settings['progress_circle_subtitle'],
                'config'          => [
                    'size'               =>  ( ! empty( $settings['progress_circle_style_global_circle_size']['size'] ) ) ? $settings['progress_circle_style_global_circle_size']['size'] : 100,
                    'stroke'              =>  ( ! empty( $settings['progress_circle_style_global_stroke']['size'] ) ) ? $settings['progress_circle_style_global_stroke']['size'] : 'auto',
                    'strokeType'          =>  $settings['progress_circle_style_global_stroke_type'],
                    'strokeColor'         =>  ( ! empty( $settings['progress_circle_style_global_value_color_stroke'] ) ) ? $settings['progress_circle_style_global_value_color_stroke'] : '#6ec1e4',
                    'strokeGradientA'     =>  ( ! empty( $settings['progress_circle_style_global_value_gradient_a_stroke'] ) ) ? $settings['progress_circle_style_global_value_gradient_a_stroke'] : '#6ec1e4',
                    'strokeGradientB'     =>  ( ! empty( $settings['progress_circle_style_global_value_gradient_b_stroke'] ) ) ? $settings['progress_circle_style_global_value_gradient_b_stroke'] : '#b6e0f1',
                    'strokeGradientAngle' =>  ( ! empty( $settings['progress_circle_style_global_value_gradient_angle'] ) ) ? $settings['progress_circle_style_global_value_gradient_angle'] : 45,
                    'strokeGB'            =>  ( ! empty( $settings['progress_circle_style_global_bg_stroke'] ) ) ? $settings['progress_circle_style_global_bg_stroke'] : '#e6e9ec',
                    'duration'            =>  ( ! empty( $settings['progress_circle_style_global_duration'] ) ) ? $settings['progress_circle_style_global_duration'] : 1000,
                    'angle'               =>  ( ! empty( $settings['progress_circle_style_global_angle']['size'] ) ) ? $settings['progress_circle_style_global_angle']['size'] : 4.7,
                    'linecap'             =>  $settings['progress_circle_style_global_linecap']
                ]

            ];
        }

        //icon font / svg
        if( isset($settings['progress_bar_icon']['value']) ){
            print ('<div class="wdes-icon-data-move">');
            Icons_Manager::render_icon( $settings['progress_bar_icon'], [ 'aria-hidden' => 'true' ] );
            print ('</div>');
        }

        //class for process type
        if( $settings['progress_type'] === 'bar' ){

            $progress_type_class = 'wdes-progress-bar-' . $settings['progress_bar_presets'];

        }else{

            $progress_type_class = 'wdes-progress-bar-' . $settings['progress_type'];

        }

        printf ( '<div class="wdes-progress %2$s" %1$s></div>', $this->convert_settings_json($progress_settings, 'progress-settings'), $progress_type_class );



    }


}